Module: Devise::Test

Defined in:
lib/devise/test/integration_helpers.rb,
lib/devise.rb,
lib/devise/test/controller_helpers.rb

Overview

Devise::Test::IntegrationHelpers is a helper module for facilitating authentication on Rails integration tests to bypass the required steps for signin in or signin out a record.

Examples

class PostsTest < ActionDispatch::IntegrationTest include Devise::Test::IntegrationHelpers

test 'authenticated users can see posts' do
  users(:bob)

 get '/posts'
 assert_response :success
end

end

Defined Under Namespace

Modules: ControllerHelpers, IntegrationHelpers